/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6-DataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"

#line 29 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 33 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 36 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 39 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 33 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 45 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 48 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 51 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 361 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 54 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 57 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 60 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 63 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 81 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtGui/qvectornd.sip"
#include <qvectornd.h>
#line 66 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 71 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 277 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 254 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 86 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 89 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 92 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 135 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 95 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 100 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 103 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 106 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 25 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qflags.sip"
#include <qglobal.h>
#line 109 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 112 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt6/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 115 "/build/pyqt6-datavisualization/src/pyqt6_datavisualization-6.11.0/build/QtDataVisualization/sipQtDataVisualizationQSurface3DSeries.cpp"


class sipQSurface3DSeries : public ::QSurface3DSeries
{
public:
    sipQSurface3DSeries(::QSurfaceDataProxy*, ::QObject*);
    sipQSurface3DSeries(::QObject*);
    virtual ~sipQSurface3DSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQSurface3DSeries(const sipQSurface3DSeries &);
    sipQSurface3DSeries &operator = (const sipQSurface3DSeries &);

    char sipPyMethods[7];
};

sipQSurface3DSeries::sipQSurface3DSeries(::QSurfaceDataProxy*a0, ::QObject*a1): ::QSurface3DSeries(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSurface3DSeries::sipQSurface3DSeries(::QObject*a0): ::QSurface3DSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQSurface3DSeries::~sipQSurface3DSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQSurface3DSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QSurface3DSeries);

    return ::QSurface3DSeries::metaObject();
}

int sipQSurface3DSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QSurface3DSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QSurface3DSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQSurface3DSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QSurface3DSeries, _clname, &sipCpp) ? sipCpp : ::QSurface3DSeries::qt_metacast(_clname));
}

void sipQSurface3DSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QSurface3DSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurface3DSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QSurface3DSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurface3DSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QSurface3DSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurface3DSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QSurface3DSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_21(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQSurface3DSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QSurface3DSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQSurface3DSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QSurface3DSeries::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQSurface3DSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QSurface3DSeries::event(a0);

    extern bool sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QSurface3DSeries_setDataProxy, "setDataProxy(self, proxy: QSurfaceDataProxy|None)");

extern "C" {static PyObject *meth_QSurface3DSeries_setDataProxy(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setDataProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSurfaceDataProxy* a0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QSurfaceDataProxy, &a0))
        {
            sipCpp->setDataProxy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setDataProxy, doc_QSurface3DSeries_setDataProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_dataProxy, "dataProxy(self) -> QSurfaceDataProxy|None");

extern "C" {static PyObject *meth_QSurface3DSeries_dataProxy(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_dataProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QSurfaceDataProxy*sipRes;

            sipRes = sipCpp->dataProxy();

            return sipConvertFromType(sipRes, sipType_QSurfaceDataProxy, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_dataProxy, doc_QSurface3DSeries_dataProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setSelectedPoint, "setSelectedPoint(self, position: QPoint)");

extern "C" {static PyObject *meth_QSurface3DSeries_setSelectedPoint(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setSelectedPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setSelectedPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setSelectedPoint, doc_QSurface3DSeries_setSelectedPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_selectedPoint, "selectedPoint(self) -> QPoint");

extern "C" {static PyObject *meth_QSurface3DSeries_selectedPoint(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_selectedPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->selectedPoint());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_selectedPoint, doc_QSurface3DSeries_selectedPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_invalidSelectionPosition, "invalidSelectionPosition() -> QPoint");

extern "C" {static PyObject *meth_QSurface3DSeries_invalidSelectionPosition(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_invalidSelectionPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, "C", &sipSelf))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(::QSurface3DSeries::invalidSelectionPosition());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_invalidSelectionPosition, doc_QSurface3DSeries_invalidSelectionPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setFlatShadingEnabled, "setFlatShadingEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QSurface3DSeries_setFlatShadingEnabled(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setFlatShadingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QSurface3DSeries, &sipCpp, &a0))
        {
            sipCpp->setFlatShadingEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setFlatShadingEnabled, doc_QSurface3DSeries_setFlatShadingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_isFlatShadingEnabled, "isFlatShadingEnabled(self) -> bool");

extern "C" {static PyObject *meth_QSurface3DSeries_isFlatShadingEnabled(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_isFlatShadingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFlatShadingEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_isFlatShadingEnabled, doc_QSurface3DSeries_isFlatShadingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setDrawMode, "setDrawMode(self, mode: QSurface3DSeries.DrawFlag)");

extern "C" {static PyObject *meth_QSurface3DSeries_setDrawMode(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setDrawMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QFlags_0100QSurface3DSeries_DrawFlag, &a0, &a0State))
        {
            sipCpp->setDrawMode(*a0);
            sipReleaseType(a0, sipType_QFlags_0100QSurface3DSeries_DrawFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setDrawMode, doc_QSurface3DSeries_setDrawMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_drawMode, "drawMode(self) -> QSurface3DSeries.DrawFlag");

extern "C" {static PyObject *meth_QSurface3DSeries_drawMode(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_drawMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QSurface3DSeries::DrawFlags(sipCpp->drawMode());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QSurface3DSeries_DrawFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_drawMode, doc_QSurface3DSeries_drawMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_isFlatShadingSupported, "isFlatShadingSupported(self) -> bool");

extern "C" {static PyObject *meth_QSurface3DSeries_isFlatShadingSupported(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_isFlatShadingSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFlatShadingSupported();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_isFlatShadingSupported, doc_QSurface3DSeries_isFlatShadingSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setTexture, "setTexture(self, texture: QImage)");

extern "C" {static PyObject *meth_QSurface3DSeries_setTexture(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QImage, &a0))
        {
            sipCpp->setTexture(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setTexture, doc_QSurface3DSeries_setTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_texture, "texture(self) -> QImage");

extern "C" {static PyObject *meth_QSurface3DSeries_texture(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_texture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->texture());

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_texture, doc_QSurface3DSeries_texture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setTextureFile, "setTextureFile(self, filename: str|None)");

extern "C" {static PyObject *meth_QSurface3DSeries_setTextureFile(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setTextureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTextureFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setTextureFile, doc_QSurface3DSeries_setTextureFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_textureFile, "textureFile(self) -> str");

extern "C" {static PyObject *meth_QSurface3DSeries_textureFile(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_textureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->textureFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_textureFile, doc_QSurface3DSeries_textureFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_setWireframeColor, "setWireframeColor(self, color: QColor|Qt.GlobalColor|int)");

extern "C" {static PyObject *meth_QSurface3DSeries_setWireframeColor(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_setWireframeColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QSurface3DSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setWireframeColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setWireframeColor, doc_QSurface3DSeries_setWireframeColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QSurface3DSeries_wireframeColor, "wireframeColor(self) -> QColor");

extern "C" {static PyObject *meth_QSurface3DSeries_wireframeColor(PyObject *, PyObject *);}
static PyObject *meth_QSurface3DSeries_wireframeColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QSurface3DSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->wireframeColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_wireframeColor, doc_QSurface3DSeries_wireframeColor);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QSurface3DSeries(void *, const sipTypeDef *);}
static void *cast_QSurface3DSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QSurface3DSeries *sipCpp = reinterpret_cast< ::QSurface3DSeries *>(sipCppV);

    if (targetType == sipType_QSurface3DSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QAbstract3DSeries)->ctd_cast(static_cast< ::QAbstract3DSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QSurface3DSeries(void *, int);}
static void release_QSurface3DSeries(void *sipCppV, int)
{
    ::QSurface3DSeries *sipCpp = reinterpret_cast< ::QSurface3DSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QSurface3DSeries(Py_ssize_t);}
static void *array_QSurface3DSeries(Py_ssize_t sipNrElem)
{
    return new ::QSurface3DSeries[sipNrElem];
}


extern "C" {static void array_delete_QSurface3DSeries(void *);}
static void array_delete_QSurface3DSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QSurface3DSeries *>(sipCpp);
}


extern "C" {static void dealloc_QSurface3DSeries(sipSimpleWrapper *);}
static void dealloc_QSurface3DSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQSurface3DSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QSurface3DSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QSurface3DSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QSurface3DSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQSurface3DSeries *sipCpp = SIP_NULLPTR;

    {
        ::QSurfaceDataProxy* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J:|JH", sipSelf, sipType_QSurfaceDataProxy, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQSurface3DSeries(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQSurface3DSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QSurface3DSeries[] = {{22, 255, 1}};


static PyMethodDef methods_QSurface3DSeries[] = {
    {sipName_dataProxy, meth_QSurface3DSeries_dataProxy, METH_VARARGS, doc_QSurface3DSeries_dataProxy},
    {sipName_drawMode, meth_QSurface3DSeries_drawMode, METH_VARARGS, doc_QSurface3DSeries_drawMode},
    {sipName_invalidSelectionPosition, meth_QSurface3DSeries_invalidSelectionPosition, METH_VARARGS, doc_QSurface3DSeries_invalidSelectionPosition},
    {sipName_isFlatShadingEnabled, meth_QSurface3DSeries_isFlatShadingEnabled, METH_VARARGS, doc_QSurface3DSeries_isFlatShadingEnabled},
    {sipName_isFlatShadingSupported, meth_QSurface3DSeries_isFlatShadingSupported, METH_VARARGS, doc_QSurface3DSeries_isFlatShadingSupported},
    {sipName_selectedPoint, meth_QSurface3DSeries_selectedPoint, METH_VARARGS, doc_QSurface3DSeries_selectedPoint},
    {sipName_setDataProxy, meth_QSurface3DSeries_setDataProxy, METH_VARARGS, doc_QSurface3DSeries_setDataProxy},
    {sipName_setDrawMode, meth_QSurface3DSeries_setDrawMode, METH_VARARGS, doc_QSurface3DSeries_setDrawMode},
    {sipName_setFlatShadingEnabled, meth_QSurface3DSeries_setFlatShadingEnabled, METH_VARARGS, doc_QSurface3DSeries_setFlatShadingEnabled},
    {sipName_setSelectedPoint, meth_QSurface3DSeries_setSelectedPoint, METH_VARARGS, doc_QSurface3DSeries_setSelectedPoint},
    {sipName_setTexture, meth_QSurface3DSeries_setTexture, METH_VARARGS, doc_QSurface3DSeries_setTexture},
    {sipName_setTextureFile, meth_QSurface3DSeries_setTextureFile, METH_VARARGS, doc_QSurface3DSeries_setTextureFile},
    {sipName_setWireframeColor, meth_QSurface3DSeries_setWireframeColor, METH_VARARGS, doc_QSurface3DSeries_setWireframeColor},
    {sipName_texture, meth_QSurface3DSeries_texture, METH_VARARGS, doc_QSurface3DSeries_texture},
    {sipName_textureFile, meth_QSurface3DSeries_textureFile, METH_VARARGS, doc_QSurface3DSeries_textureFile},
    {sipName_wireframeColor, meth_QSurface3DSeries_wireframeColor, METH_VARARGS, doc_QSurface3DSeries_wireframeColor}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QSurface3DSeries[] = {
    {sipName_DrawWireframe, static_cast<int>(::QSurface3DSeries::DrawWireframe)},
    {sipName_DrawSurface, static_cast<int>(::QSurface3DSeries::DrawSurface)},
    {sipName_DrawSurfaceAndWireframe, static_cast<int>(::QSurface3DSeries::DrawSurfaceAndWireframe)},
    {0, 0}
};

PyDoc_STRVAR(doc_QSurface3DSeries, "\1QSurface3DSeries(dataProxy: QSurfaceDataProxy|None, parent: QObject|None = None)\n"
"QSurface3DSeries(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QSurface3DSeries[] = {
    {"wireframeColorChanged(QColor)", "\1wireframeColorChanged(self, color: QColor|Qt.GlobalColor|int)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureFileChanged(QString)", "\1textureFileChanged(self, filename: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureChanged(QImage)", "\1textureChanged(self, image: QImage)", SIP_NULLPTR, SIP_NULLPTR},
    {"drawModeChanged(QSurface3DSeries::DrawFlags)", "\1drawModeChanged(self, mode: QSurface3DSeries.DrawFlag)", SIP_NULLPTR, SIP_NULLPTR},
    {"flatShadingSupportedChanged(bool)", "\1flatShadingSupportedChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"flatShadingEnabledChanged(bool)", "\1flatShadingEnabledChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectedPointChanged(QPoint)", "\1selectedPointChanged(self, position: QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataProxyChanged(QSurfaceDataProxy*)", "\1dataProxyChanged(self, proxy: QSurfaceDataProxy|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QSurface3DSeries = {
    &::QSurface3DSeries::staticMetaObject,
    signals_QSurface3DSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QSurface3DSeries = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QSurface3DSeries,
        SIP_NULLPTR,
        &plugin_QSurface3DSeries,
    },
    {
        sipNameNr_QSurface3DSeries,
        {0, 0, 1},
        16, methods_QSurface3DSeries,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QSurface3DSeries, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QSurface3DSeries,
    -1,
    -1,
    supers_QSurface3DSeries,
    SIP_NULLPTR,
    init_type_QSurface3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QSurface3DSeries,
    SIP_NULLPTR,
    array_QSurface3DSeries,
    SIP_NULLPTR,
    release_QSurface3DSeries,
    cast_QSurface3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QSurface3DSeries,
    sizeof (::QSurface3DSeries),
};
